==> order-center-api-3.0.0-CLOUD-DEV-20220929.082649-85-sources.jar: com/tydic/dyc/oc/constants/UocEventConstant.java <==
package com.tydic.dyc.oc.constants;

/**
 * 标题:UocEventConstant
 * 说明:事件编码
 * 时间:2022/3/9 20:53
 * 作者:田桂银
 */
public class UocEventConstant {


    /**
     * 整单同步ES
     */
    public static final String UOC_ORDER_SYNC = "UOC_ORDER_SYNC";

    /**
     * 销售单创建
     */
    public static final String UOC_SALE_ORDER_SYNC = "UOCE_CREATE_ORDER";

    /**
     * 同步代办
     */
    public static final String UOCE_ES_SYNC_TODO = "UOCE_ES_SYNC_TODO";

    /**
     * 销售单同步事件
     */
    public static final String UOCE_ES_SYNC_SALE_ORDER = "UOCE_ES_SYNC_SALE_ORDER";

    /**
     * 变更单同步事件
     */
    public static final String UOCE_ES_SYNC_CHNG_ORDER = "UOCE_ES_SYNC_CHNG_ORDER";


    /**
     * 变更单同步事件
     */
    public static final String UOCE_ES_SYNC_CHNG_ORDER_HR = "UOCE_ES_SYNC_CHNG_ORDER_HR";

    /**
     * 发货单同步 到货登记
     */
    public static final String UOCE_SHIP_ARRIVA_REGIST = "UOCE_SHIP_ARRIVA_REGIST";

    /**
     * 发货单同步 到货确认/拒收
     */
    public static final String UOCE_SHIP_ARRIVA_CONFIRM_OR_REFUSE = "UOCE_SHIP_ARRIVA_CONFIRM_OR_REFUSE";

    /**
     * 发货单同步
     */
    public static final String UOC_SHIP_ORDER_SYNC = "UOCE_CREATE_SHIP";

    /**
     * 验收同步
     */
    public static final String UOC_INSP_ORDER_SYNC = "UOCE_CREATE_INSP";


    /**
     * 批量验收同步
     */
    public static final String UOC_INSP_ORDERS_SYNC = "UOCE_UPDATE_INSPS";

    /**
     * 执行单同步
     */
    public static final String UOC_IMPL_ORDER_SYNC = "UOCE_CREATE_IMPL";

    /**
     * 变更单同步
     */
    public static final String UOC_CHNG_ORDER_SYNC = "UOCE_CREATE_CHNG";

    /**
     * 销售单成交服务费
     */
    public static final String UOC_SALE_TRANSACTION_SYNC = "UOC_SALE_TRANSACTION_SYNC";

    /**
     * 验收单成交服务费
     */
    public static final String UOC_INSP_TRANSACTION_SYNC = "UOC_INSP_TRANSACTION_SYNC";

	/**
	 * 销售单任务提交同步销售单索引
	 */
	public static final String UOC_SALE_COMMIT_SYNC = "UOCE_SALE_COMMIT";

	/**
	 * 单据任务提交同步销售单索引
	 */
	public static final String UOCE_ORDER_COMMIT_SYNC = "UOCE_ORDER_COMMIT";

	/**
	 * 单据结算关联状态更新
	 */
	public static final String UOCE_ORDER_SELLTE_SYNC = "UOCE_ORDER_SELLTE_SYNC";


    /**
     * 售后单同步
     */
    public static final String UOCE_ORDER_AFTER_SYNC = "UOCE_CREATE_AFTER";

    /**
     * 售后单同步确认
     */
    public static final String UOCE_ORDER_AFTER_SYNC_HR = "UOCE_CREATE_AFTER_HR";


}

==> order-center-api-3.1.0-CLOUD-DEV-20230801.034020-62-sources.jar: com/tydic/dyc/oc/constants/UocEventConstant.java <==
package com.tydic.dyc.oc.constants;

/**
 * 标题:UocEventConstant
 * 说明:事件编码
 * 时间:2022/3/9 20:53
 * 作者:田桂银
 */
public class UocEventConstant {


    /**
     * 整单同步ES
     */
    public static final String UOC_ORDER_SYNC = "UOC_ORDER_SYNC";

    /**
     * 销售单创建
     */
    public static final String UOC_SALE_ORDER_SYNC = "UOCE_CREATE_ORDER";

    /**
     * 同步代办
     */
    public static final String UOCE_ES_SYNC_TODO = "UOCE_ES_SYNC_TODO";

    /**
     * 销售单同步事件
     */
    public static final String UOCE_ES_SYNC_SALE_ORDER = "UOCE_ES_SYNC_SALE_ORDER";

    /**
     * 变更单同步事件
     */
    public static final String UOCE_ES_SYNC_CHNG_ORDER = "UOCE_ES_SYNC_CHNG_ORDER";


    /**
     * 变更单同步事件
     */
    public static final String UOCE_ES_SYNC_CHNG_ORDER_HR = "UOCE_ES_SYNC_CHNG_ORDER_HR";

    /**
     * 发货单同步 到货登记
     */
    public static final String UOCE_SHIP_ARRIVA_REGIST = "UOCE_SHIP_ARRIVA_REGIST";

    /**
     * 发货单同步 到货确认/拒收
     */
    public static final String UOCE_SHIP_ARRIVA_CONFIRM_OR_REFUSE = "UOCE_SHIP_ARRIVA_CONFIRM_OR_REFUSE";

    /**
     * 发货单同步
     */
    public static final String UOC_SHIP_ORDER_SYNC = "UOCE_CREATE_SHIP";

    /**
     * 验收同步
     */
    public static final String UOC_INSP_ORDER_SYNC = "UOCE_CREATE_INSP";


    /**
     * 批量验收同步
     */
    public static final String UOC_INSP_ORDERS_SYNC = "UOCE_UPDATE_INSPS";

    /**
     * 执行单同步
     */
    public static final String UOC_IMPL_ORDER_SYNC = "UOCE_CREATE_IMPL";

    /**
     * 变更单同步
     */
    public static final String UOC_CHNG_ORDER_SYNC = "UOCE_CREATE_CHNG";

    /**
     * 销售单成交服务费
     */
    public static final String UOC_SALE_TRANSACTION_SYNC = "UOC_SALE_TRANSACTION_SYNC";

    /**
     * 验收单成交服务费
     */
    public static final String UOC_INSP_TRANSACTION_SYNC = "UOC_INSP_TRANSACTION_SYNC";

	/**
	 * 销售单任务提交同步销售单索引
	 */
	public static final String UOC_SALE_COMMIT_SYNC = "UOCE_SALE_COMMIT";

	/**
	 * 单据任务提交同步销售单索引
	 */
	public static final String UOCE_ORDER_COMMIT_SYNC = "UOCE_ORDER_COMMIT";

	/**
	 * 单据结算关联状态更新
	 */
	public static final String UOCE_ORDER_SELLTE_SYNC = "UOCE_ORDER_SELLTE_SYNC";


    /**
     * 售后单同步
     */
    public static final String UOCE_ORDER_AFTER_SYNC = "UOCE_CREATE_AFTER";

    /**
     * 售后单同步确认
     */
    public static final String UOCE_ORDER_AFTER_SYNC_HR = "UOCE_CREATE_AFTER_HR";

    /**
     * 操作类型1 发起议价,2 议价单终止,3 供应商已报价,4. 重新议价,5. 下单成功
     */
    public static final class BARGAINING_OPER_TYPE {
        /**
         * 1：发起议价
         */
        public static final Integer CREATE = 1;
        /**
         * 2：议价单终止
         */
        public static final Integer CANCEL = 2;
        /**
         * 3：供应商已报价
         */
        public static final Integer QUOTATION = 3;
        /**
         * 4：重新议价
         */
        public static final Integer RE_QUOTATION= 4;
        /**
         * 5：下单成功
         */
        public static final Integer ORDER = 5;
    }


}
